summaryrefslogtreecommitdiff
path: root/libtiff/tiffio.h
diff options
context:
space:
mode:
authorJoris Van Damme <joris.at.lebbeke@skynet.be>2007-06-28 12:43:07 +0000
committerJoris Van Damme <joris.at.lebbeke@skynet.be>2007-06-28 12:43:07 +0000
commit579d12785cc0b0b76a776ef6ee613fad55499aae (patch)
treee37c106a5ade3a5da2baa7b005dac0927b1e2e49 /libtiff/tiffio.h
parent100fb620daeb9e350372a265c5089b7238ad281f (diff)
downloadlibtiff-git-579d12785cc0b0b76a776ef6ee613fad55499aae.tar.gz
BigTIFF upgrade: insertion of reserved member in TIFFFieldInfo structure
Diffstat (limited to 'libtiff/tiffio.h')
-rw-r--r--libtiff/tiffio.h41
1 files changed, 21 insertions, 20 deletions
diff --git a/libtiff/tiffio.h b/libtiff/tiffio.h
index 5a2324db..6aade9f4 100644
--- a/libtiff/tiffio.h
+++ b/libtiff/tiffio.h
@@ -1,4 +1,4 @@
-/* $Id: tiffio.h,v 1.71 2007-06-27 16:09:58 joris Exp $ */
+/* $Id: tiffio.h,v 1.72 2007-06-28 12:43:08 joris Exp $ */
/*
* Copyright (c) 1988-1997 Sam Leffler
@@ -299,27 +299,28 @@ extern void _TIFFfree(void* p);
extern int TIFFGetTagListCount( TIFF * );
extern uint32 TIFFGetTagListEntry( TIFF *, int tag_index );
-#define TIFF_ANY TIFF_NOTYPE /* for field descriptor searching */
-#define TIFF_VARIABLE -1 /* marker for variable length tags */
-#define TIFF_SPP -2 /* marker for SamplesPerPixel tags */
-#define TIFF_VARIABLE2 -3 /* marker for uint32 var-length tags */
+#define TIFF_ANY TIFF_NOTYPE /* for field descriptor searching */
+#define TIFF_VARIABLE -1 /* marker for variable length tags */
+#define TIFF_SPP -2 /* marker for SamplesPerPixel tags */
+#define TIFF_VARIABLE2 -3 /* marker for uint32 var-length tags */
#define FIELD_CUSTOM 65
struct _TIFFFieldInfoArray;
typedef struct {
- uint32 field_tag; /* field's tag */
- short field_readcount; /* read count/TIFF_VARIABLE/TIFF_SPP */
- short field_writecount; /* write count/TIFF_VARIABLE */
- TIFFDataType field_type; /* type of associated data */
- TIFFSetGetFieldType set_field_type; /* type to be passed to TIFFSetField */
- TIFFSetGetFieldType get_field_type; /* type to be passed to TIFFGetField */
- unsigned short field_bit; /* bit in fieldsset bit vector */
- unsigned char field_oktochange; /* if true, can change while writing */
- unsigned char field_passcount; /* if true, pass dir count on set */
- char* field_name; /* ASCII name */
- const struct _TIFFFieldInfoArray* field_subfields;
+ uint32 field_tag; /* field's tag */
+ short field_readcount; /* read count/TIFF_VARIABLE/TIFF_SPP */
+ short field_writecount; /* write count/TIFF_VARIABLE */
+ TIFFDataType field_type; /* type of associated data */
+ uint32 reserved; /* reserved for future extension */
+ TIFFSetGetFieldType set_field_type; /* type to be passed to TIFFSetField */
+ TIFFSetGetFieldType get_field_type; /* type to be passed to TIFFGetField */
+ unsigned short field_bit; /* bit in fieldsset bit vector */
+ unsigned char field_oktochange; /* if true, can change while writing */
+ unsigned char field_passcount; /* if true, pass dir count on set */
+ char* field_name; /* ASCII name */
+ const struct _TIFFFieldInfoArray* field_subfields; /* if field points to child ifds, child ifd field definition array */
} TIFFFieldInfo;
typedef enum {
@@ -329,10 +330,10 @@ typedef enum {
} TIFFFieldInfoArrayType;
typedef struct _TIFFFieldInfoArray{
- TIFFFieldInfoArrayType type;
- uint32 allocated;
- uint32 used;
- const TIFFFieldInfo* fieldinfo;
+ TIFFFieldInfoArrayType type; /* array type, will be used to determine if IFD is image and such */
+ uint32 allocated; /* allocated size, 0 if constant, other if modified by future definition extension support */
+ uint32 used; /* size of array */
+ const TIFFFieldInfo* fieldinfo; /* actual field info */
} TIFFFieldInfoArray;
typedef struct _TIFFTagValue {